Index: /trunk/psLib/src/collections/psBitSet.c
===================================================================
--- /trunk/psLib/src/collections/psBitSet.c	(revision 951)
+++ /trunk/psLib/src/collections/psBitSet.c	(revision 952)
@@ -4,12 +4,12 @@
  *
  *  Bit masks are useful tools for toggling various flags and options. This set of functions module provides
- *  a mechanism to create an array of bits of arbitrary length and manipulate them with basic binary 
+ *  a mechanism to create an array of bits of arbitrary length and manipulate them with basic binary
  *  operations. A print function is also provided to display the entire set of bits in binary format as a
  *  string.
  *
  *  @author Ross Harman, MHPCC
- *   
- *  @version $Revision: 1.4 $ $Name: not supported by cvs2svn $
- *  @date $Date: 2004-06-03 00:32:32 $
+ *
+ *  @version $Revision: 1.5 $ $Name: not supported by cvs2svn $
+ *  @date $Date: 2004-06-09 21:18:24 $
  *
  *  Copyright 2004 Maui High Performance Computing Center, University of Hawaii
@@ -80,5 +80,5 @@
 
     if(n <= 0) {
-        psError(__func__, " : Line %d - Allocation size must be >= 0: size = %d\n", __LINE__, n);
+        psError(__func__, " : Line %d - Allocation size must be > 0: size = %d\n", __LINE__, n);
         return 0;
     }
Index: /trunk/psLib/src/types/psBitSet.c
===================================================================
--- /trunk/psLib/src/types/psBitSet.c	(revision 951)
+++ /trunk/psLib/src/types/psBitSet.c	(revision 952)
@@ -4,12 +4,12 @@
  *
  *  Bit masks are useful tools for toggling various flags and options. This set of functions module provides
- *  a mechanism to create an array of bits of arbitrary length and manipulate them with basic binary 
+ *  a mechanism to create an array of bits of arbitrary length and manipulate them with basic binary
  *  operations. A print function is also provided to display the entire set of bits in binary format as a
  *  string.
  *
  *  @author Ross Harman, MHPCC
- *   
- *  @version $Revision: 1.4 $ $Name: not supported by cvs2svn $
- *  @date $Date: 2004-06-03 00:32:32 $
+ *
+ *  @version $Revision: 1.5 $ $Name: not supported by cvs2svn $
+ *  @date $Date: 2004-06-09 21:18:24 $
  *
  *  Copyright 2004 Maui High Performance Computing Center, University of Hawaii
@@ -80,5 +80,5 @@
 
     if(n <= 0) {
-        psError(__func__, " : Line %d - Allocation size must be >= 0: size = %d\n", __LINE__, n);
+        psError(__func__, " : Line %d - Allocation size must be > 0: size = %d\n", __LINE__, n);
         return 0;
     }
Index: /trunk/psLib/test/collections/tst_psBitSet_06.c
===================================================================
--- /trunk/psLib/test/collections/tst_psBitSet_06.c	(revision 951)
+++ /trunk/psLib/test/collections/tst_psBitSet_06.c	(revision 952)
@@ -6,10 +6,11 @@
  *     A)  Create two psBitSets
  *     B)  Perform invalid binary operation with psBitSets
- *     C)  Free psBitSets
+ *     C)  Attempt to create negative size bitset
+ *     D)  Free psBitSets
  *
  *  @author  Ross Harman, MHPCC
  *
- *  @version $Revision: 1.3 $  $Name: not supported by cvs2svn $
- *  @date  $Date: 2004-05-18 19:22:34 $
+ *  @version $Revision: 1.4 $  $Name: not supported by cvs2svn $
+ *  @date  $Date: 2004-06-09 21:18:53 $
  *
  *  Copyright 2004 Maui High Performance Computing Center, University of Hawaii
@@ -47,5 +48,12 @@
 
 
-    // Test C - Free psBitSets
+    // Test C - Attempt to create negative size bitset
+    printNegativeTestHeader(stdout,"psBitSet", "Create negative size bitset",
+                            "Allocation size must be >= 0: size = -4", 0);
+    psBitSetAlloc(-4);
+    printFooter(stdout, "psBitSet", "Create negative size bitset", true);
+
+
+    // Test D - Free psBitSets
     printPositiveTestHeader(stdout, "psBitSet", "Free psBitSets");
     psBitSetFree(bs1);
